darkhistory.spec.transferfunction — DarkHistory documentation

# darkhistory.spec.transferfunction

Functions and classes for processing transfer functions.

Classes

`TransFuncAtEnergy`(spec_arr[, eng, in_eng, …]) | Transfer function at a given injection energy.
`TransFuncAtRedshift`(spec_arr[, eng, in_eng, …]) | Transfer function at a given redshift.

#### Previous topic

darkhistory.spec.transferfunclist.TransferFuncListArray

#### Next topic

darkhistory.spec.transferfunction.TransFuncAtEnergy

### This Page

Show Source